﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using C1.WPF.C1Chart;

namespace Wpf_Chart_FillFinancialCandle
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void HighLowOpenCloseSeries_PlotElementLoaded(object sender, EventArgs e)
        {
            PlotElement pe = sender as PlotElement;
            
            // Retrieve the values of the Candle Element
            double open = (double)pe.DataPoint["OpenValues"];
            double close = (double)pe.DataPoint["CloseValues"];
            double low = (double)pe.DataPoint["LowValues"];
            double high = (double)pe.DataPoint["HighValues"];

            // Declare a new Rect element to replace the original PlotElement
            Rectangle rect = new Rectangle();
            // Get the region of the Current PlotElement
            Rect rct = (((System.Windows.Shapes.Shape)(pe)).RenderedGeometry).Bounds;
            
            // Get the Parent Container of the PlotElements
            Canvas cvs = pe.Parent as Canvas;
            // Add the new Rectangle to the Parent Container
            cvs.Children.Add(rect);

            // Retrieve the Chart Coordinates based on the High/Low and Open/Close values
            // These points are used to position the new Rectangle
            Point openPoint = c1Chart1.View.AxisX.PointFromData(new Point(pe.DataPoint.PointIndex + 1, open));
            Point closePoint = c1Chart1.View.AxisX.PointFromData(new Point(pe.DataPoint.PointIndex + 1, close));

            Point lowPoint = c1Chart1.View.AxisX.PointFromData(new Point(pe.DataPoint.PointIndex + 1, low));
            Point HighPoint = c1Chart1.View.AxisX.PointFromData(new Point(pe.DataPoint.PointIndex + 1, high));
            
            Canvas.SetLeft(rect, closePoint.X - (rct.Width / 2));
            rect.Width = rct.Width;
            rect.Height = lowPoint.Y - closePoint.Y;

            // For Positive Candle Values
            if (close > open)
            {                
                Canvas.SetTop(rect, closePoint.Y - 1);
                rect.Fill = Brushes.GreenYellow;                
            }
            // For Negative Candle Values
            else
            {                
                Canvas.SetTop(rect, openPoint.Y - 1);
                rect.Fill = Brushes.Red;
            }

            // Add Line for marking Low/High Points (Candle Wick)
            Line ln = new Line();
            ln.StrokeThickness = 1;
            ln.Stroke = new SolidColorBrush(Colors.Blue);
            ln.X1 = lowPoint.X; ln.Y1 = lowPoint.Y;
            ln.X2 = HighPoint.X; ln.Y2 = HighPoint.Y;
            cvs.Children.Add(ln);

            // Set Z index for Candle to bring Close/Open rectangel on top of the Low/High Line
            Canvas.SetZIndex(rect, 1);

            // Remove the original PlotElement
            cvs.Children.Remove(pe);

        }
    }
}
